# coding: utf-8

"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from Monei.configuration import Configuration


class ConfirmPaymentRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'payment_token': 'str',
        'payment_method': 'ConfirmPaymentRequestPaymentMethod',
        'generate_payment_token': 'bool',
        'customer': 'PaymentCustomer',
        'billing_details': 'PaymentBillingDetails',
        'shipping_details': 'PaymentShippingDetails'
    }

    attribute_map = {
        'payment_token': 'paymentToken',
        'payment_method': 'paymentMethod',
        'generate_payment_token': 'generatePaymentToken',
        'customer': 'customer',
        'billing_details': 'billingDetails',
        'shipping_details': 'shippingDetails'
    }

    def __init__(self, payment_token=None, payment_method=None, generate_payment_token=False, customer=None, billing_details=None, shipping_details=None, local_vars_configuration=None):  # noqa: E501
        """ConfirmPaymentRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._payment_token = None
        self._payment_method = None
        self._generate_payment_token = None
        self._customer = None
        self._billing_details = None
        self._shipping_details = None
        self.discriminator = None

        self.payment_token = payment_token
        if payment_method is not None:
            self.payment_method = payment_method
        if generate_payment_token is not None:
            self.generate_payment_token = generate_payment_token
        if customer is not None:
            self.customer = customer
        if billing_details is not None:
            self.billing_details = billing_details
        if shipping_details is not None:
            self.shipping_details = shipping_details

    @property
    def payment_token(self):
        """Gets the payment_token of this ConfirmPaymentRequest.  # noqa: E501

        A payment token generated by monei.js [Components](https://docs.monei.com/docs/monei-js-overview) or a paymentToken [saved after a previous successful payment](https://docs.monei.com/docs/save-payment-method).   # noqa: E501

        :return: The payment_token of this ConfirmPaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_token

    @payment_token.setter
    def payment_token(self, payment_token):
        """Sets the payment_token of this ConfirmPaymentRequest.

        A payment token generated by monei.js [Components](https://docs.monei.com/docs/monei-js-overview) or a paymentToken [saved after a previous successful payment](https://docs.monei.com/docs/save-payment-method).   # noqa: E501

        :param payment_token: The payment_token of this ConfirmPaymentRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and payment_token is None:  # noqa: E501
            raise ValueError("Invalid value for `payment_token`, must not be `None`")  # noqa: E501

        self._payment_token = payment_token

    @property
    def payment_method(self):
        """Gets the payment_method of this ConfirmPaymentRequest.  # noqa: E501


        :return: The payment_method of this ConfirmPaymentRequest.  # noqa: E501
        :rtype: ConfirmPaymentRequestPaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this ConfirmPaymentRequest.


        :param payment_method: The payment_method of this ConfirmPaymentRequest.  # noqa: E501
        :type: ConfirmPaymentRequestPaymentMethod
        """

        self._payment_method = payment_method

    @property
    def generate_payment_token(self):
        """Gets the generate_payment_token of this ConfirmPaymentRequest.  # noqa: E501

        If set to true a permanent token that represents a payment method used in the payment will be generated.   # noqa: E501

        :return: The generate_payment_token of this ConfirmPaymentRequest.  # noqa: E501
        :rtype: bool
        """
        return self._generate_payment_token

    @generate_payment_token.setter
    def generate_payment_token(self, generate_payment_token):
        """Sets the generate_payment_token of this ConfirmPaymentRequest.

        If set to true a permanent token that represents a payment method used in the payment will be generated.   # noqa: E501

        :param generate_payment_token: The generate_payment_token of this ConfirmPaymentRequest.  # noqa: E501
        :type: bool
        """

        self._generate_payment_token = generate_payment_token

    @property
    def customer(self):
        """Gets the customer of this ConfirmPaymentRequest.  # noqa: E501


        :return: The customer of this ConfirmPaymentRequest.  # noqa: E501
        :rtype: PaymentCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this ConfirmPaymentRequest.


        :param customer: The customer of this ConfirmPaymentRequest.  # noqa: E501
        :type: PaymentCustomer
        """

        self._customer = customer

    @property
    def billing_details(self):
        """Gets the billing_details of this ConfirmPaymentRequest.  # noqa: E501


        :return: The billing_details of this ConfirmPaymentRequest.  # noqa: E501
        :rtype: PaymentBillingDetails
        """
        return self._billing_details

    @billing_details.setter
    def billing_details(self, billing_details):
        """Sets the billing_details of this ConfirmPaymentRequest.


        :param billing_details: The billing_details of this ConfirmPaymentRequest.  # noqa: E501
        :type: PaymentBillingDetails
        """

        self._billing_details = billing_details

    @property
    def shipping_details(self):
        """Gets the shipping_details of this ConfirmPaymentRequest.  # noqa: E501


        :return: The shipping_details of this ConfirmPaymentRequest.  # noqa: E501
        :rtype: PaymentShippingDetails
        """
        return self._shipping_details

    @shipping_details.setter
    def shipping_details(self, shipping_details):
        """Sets the shipping_details of this ConfirmPaymentRequest.


        :param shipping_details: The shipping_details of this ConfirmPaymentRequest.  # noqa: E501
        :type: PaymentShippingDetails
        """

        self._shipping_details = shipping_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfirmPaymentRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfirmPaymentRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from Monei.configuration import Configuration


class SubscriptionPaymentMethodCard(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'country': 'str',
        'brand': 'str',
        'type': 'str',
        'three_d_secure': 'bool',
        'three_d_secure_version': 'str',
        'expiration': 'int',
        'last4': 'str'
    }

    attribute_map = {
        'country': 'country',
        'brand': 'brand',
        'type': 'type',
        'three_d_secure': 'threeDSecure',
        'three_d_secure_version': 'threeDSecureVersion',
        'expiration': 'expiration',
        'last4': 'last4'
    }

    def __init__(self, country=None, brand=None, type=None, three_d_secure=None, three_d_secure_version=None, expiration=None, last4=None, local_vars_configuration=None):  # noqa: E501
        """SubscriptionPaymentMethodCard - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._country = None
        self._brand = None
        self._type = None
        self._three_d_secure = None
        self._three_d_secure_version = None
        self._expiration = None
        self._last4 = None
        self.discriminator = None

        if country is not None:
            self.country = country
        if brand is not None:
            self.brand = brand
        if type is not None:
            self.type = type
        if three_d_secure is not None:
            self.three_d_secure = three_d_secure
        if three_d_secure_version is not None:
            self.three_d_secure_version = three_d_secure_version
        if expiration is not None:
            self.expiration = expiration
        if last4 is not None:
            self.last4 = last4

    @property
    def country(self):
        """Gets the country of this SubscriptionPaymentMethodCard.  # noqa: E501

        Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).  # noqa: E501

        :return: The country of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this SubscriptionPaymentMethodCard.

        Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).  # noqa: E501

        :param country: The country of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def brand(self):
        """Gets the brand of this SubscriptionPaymentMethodCard.  # noqa: E501

        Card brand.  # noqa: E501

        :return: The brand of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._brand

    @brand.setter
    def brand(self, brand):
        """Sets the brand of this SubscriptionPaymentMethodCard.

        Card brand.  # noqa: E501

        :param brand: The brand of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: str
        """
        allowed_values = ["visa", "mastercard", "diners", "amex", "jcb", "unionpay", "unknown"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and brand not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `brand` ({0}), must be one of {1}"  # noqa: E501
                .format(brand, allowed_values)
            )

        self._brand = brand

    @property
    def type(self):
        """Gets the type of this SubscriptionPaymentMethodCard.  # noqa: E501

        Card type `debit` or `credit`.  # noqa: E501

        :return: The type of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SubscriptionPaymentMethodCard.

        Card type `debit` or `credit`.  # noqa: E501

        :param type: The type of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: str
        """
        allowed_values = ["debit", "credit"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def three_d_secure(self):
        """Gets the three_d_secure of this SubscriptionPaymentMethodCard.  # noqa: E501

        Wether this transaction used 3D Secure authentication.  # noqa: E501

        :return: The three_d_secure of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: bool
        """
        return self._three_d_secure

    @three_d_secure.setter
    def three_d_secure(self, three_d_secure):
        """Sets the three_d_secure of this SubscriptionPaymentMethodCard.

        Wether this transaction used 3D Secure authentication.  # noqa: E501

        :param three_d_secure: The three_d_secure of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: bool
        """

        self._three_d_secure = three_d_secure

    @property
    def three_d_secure_version(self):
        """Gets the three_d_secure_version of this SubscriptionPaymentMethodCard.  # noqa: E501

        The protocol version of the 3DS challenge.  # noqa: E501

        :return: The three_d_secure_version of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._three_d_secure_version

    @three_d_secure_version.setter
    def three_d_secure_version(self, three_d_secure_version):
        """Sets the three_d_secure_version of this SubscriptionPaymentMethodCard.

        The protocol version of the 3DS challenge.  # noqa: E501

        :param three_d_secure_version: The three_d_secure_version of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._three_d_secure_version = three_d_secure_version

    @property
    def expiration(self):
        """Gets the expiration of this SubscriptionPaymentMethodCard.  # noqa: E501

        Time at which the card will expire. Measured in seconds since the Unix epoch.   # noqa: E501

        :return: The expiration of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: int
        """
        return self._expiration

    @expiration.setter
    def expiration(self, expiration):
        """Sets the expiration of this SubscriptionPaymentMethodCard.

        Time at which the card will expire. Measured in seconds since the Unix epoch.   # noqa: E501

        :param expiration: The expiration of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: int
        """

        self._expiration = expiration

    @property
    def last4(self):
        """Gets the last4 of this SubscriptionPaymentMethodCard.  # noqa: E501

        The last four digits of the card.  # noqa: E501

        :return: The last4 of this SubscriptionPaymentMethodCard.  # noqa: E501
        :rtype: str
        """
        return self._last4

    @last4.setter
    def last4(self, last4):
        """Sets the last4 of this SubscriptionPaymentMethodCard.

        The last four digits of the card.  # noqa: E501

        :param last4: The last4 of this SubscriptionPaymentMethodCard.  # noqa: E501
        :type: str
        """

        self._last4 = last4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionPaymentMethodCard):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubscriptionPaymentMethodCard):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from Monei.configuration import Configuration


class SubscriptionPaymentMethod(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'method': 'str',
        'card': 'PaymentPaymentMethodCard'
    }

    attribute_map = {
        'method': 'method',
        'card': 'card'
    }

    def __init__(self, method=None, card=None, local_vars_configuration=None):  # noqa: E501
        """SubscriptionPaymentMethod - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._method = None
        self._card = None
        self.discriminator = None

        if method is not None:
            self.method = method
        if card is not None:
            self.card = card

    @property
    def method(self):
        """Gets the method of this SubscriptionPaymentMethod.  # noqa: E501

        Subscription method type.  # noqa: E501

        :return: The method of this SubscriptionPaymentMethod.  # noqa: E501
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method):
        """Sets the method of this SubscriptionPaymentMethod.

        Subscription method type.  # noqa: E501

        :param method: The method of this SubscriptionPaymentMethod.  # noqa: E501
        :type: str
        """
        allowed_values = ["card"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and method not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `method` ({0}), must be one of {1}"  # noqa: E501
                .format(method, allowed_values)
            )

        self._method = method

    @property
    def card(self):
        """Gets the card of this SubscriptionPaymentMethod.  # noqa: E501


        :return: The card of this SubscriptionPaymentMethod.  # noqa: E501
        :rtype: PaymentPaymentMethodCard
        """
        return self._card

    @card.setter
    def card(self, card):
        """Sets the card of this SubscriptionPaymentMethod.


        :param card: The card of this SubscriptionPaymentMethod.  # noqa: E501
        :type: PaymentPaymentMethodCard
        """

        self._card = card

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubscriptionPaymentMethod):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SubscriptionPaymentMethod):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from Monei.configuration import Configuration


class PaymentSessionDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ip': 'str',
        'country_code': 'str',
        'lang': 'str',
        'device_type': 'str',
        'device_model': 'str',
        'browser': 'str',
        'browser_version': 'str',
        'os': 'str',
        'os_version': 'str',
        'source': 'str',
        'source_version': 'str',
        'user_agent': 'str',
        'browser_accept': 'str',
        'browser_color_depth': 'int',
        'browser_screen_height': 'int',
        'browser_screen_width': 'int',
        'browser_timezone_offset': 'str'
    }

    attribute_map = {
        'ip': 'ip',
        'country_code': 'countryCode',
        'lang': 'lang',
        'device_type': 'deviceType',
        'device_model': 'deviceModel',
        'browser': 'browser',
        'browser_version': 'browserVersion',
        'os': 'os',
        'os_version': 'osVersion',
        'source': 'source',
        'source_version': 'sourceVersion',
        'user_agent': 'userAgent',
        'browser_accept': 'browserAccept',
        'browser_color_depth': 'browserColorDepth',
        'browser_screen_height': 'browserScreenHeight',
        'browser_screen_width': 'browserScreenWidth',
        'browser_timezone_offset': 'browserTimezoneOffset'
    }

    def __init__(self, ip=None, country_code=None, lang=None, device_type=None, device_model=None, browser=None, browser_version=None, os=None, os_version=None, source=None, source_version=None, user_agent=None, browser_accept=None, browser_color_depth=None, browser_screen_height=None, browser_screen_width=None, browser_timezone_offset=None, local_vars_configuration=None):  # noqa: E501
        """PaymentSessionDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ip = None
        self._country_code = None
        self._lang = None
        self._device_type = None
        self._device_model = None
        self._browser = None
        self._browser_version = None
        self._os = None
        self._os_version = None
        self._source = None
        self._source_version = None
        self._user_agent = None
        self._browser_accept = None
        self._browser_color_depth = None
        self._browser_screen_height = None
        self._browser_screen_width = None
        self._browser_timezone_offset = None
        self.discriminator = None

        if ip is not None:
            self.ip = ip
        if country_code is not None:
            self.country_code = country_code
        if lang is not None:
            self.lang = lang
        if device_type is not None:
            self.device_type = device_type
        if device_model is not None:
            self.device_model = device_model
        if browser is not None:
            self.browser = browser
        if browser_version is not None:
            self.browser_version = browser_version
        if os is not None:
            self.os = os
        if os_version is not None:
            self.os_version = os_version
        if source is not None:
            self.source = source
        if source_version is not None:
            self.source_version = source_version
        if user_agent is not None:
            self.user_agent = user_agent
        if browser_accept is not None:
            self.browser_accept = browser_accept
        if browser_color_depth is not None:
            self.browser_color_depth = browser_color_depth
        if browser_screen_height is not None:
            self.browser_screen_height = browser_screen_height
        if browser_screen_width is not None:
            self.browser_screen_width = browser_screen_width
        if browser_timezone_offset is not None:
            self.browser_timezone_offset = browser_timezone_offset

    @property
    def ip(self):
        """Gets the ip of this PaymentSessionDetails.  # noqa: E501

        The IP address where the operation originated.  # noqa: E501

        :return: The ip of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """Sets the ip of this PaymentSessionDetails.

        The IP address where the operation originated.  # noqa: E501

        :param ip: The ip of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._ip = ip

    @property
    def country_code(self):
        """Gets the country_code of this PaymentSessionDetails.  # noqa: E501

        Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).  # noqa: E501

        :return: The country_code of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._country_code

    @country_code.setter
    def country_code(self, country_code):
        """Sets the country_code of this PaymentSessionDetails.

        Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).  # noqa: E501

        :param country_code: The country_code of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._country_code = country_code

    @property
    def lang(self):
        """Gets the lang of this PaymentSessionDetails.  # noqa: E501

        Two-letter language code ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1)).  # noqa: E501

        :return: The lang of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._lang

    @lang.setter
    def lang(self, lang):
        """Sets the lang of this PaymentSessionDetails.

        Two-letter language code ([ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1)).  # noqa: E501

        :param lang: The lang of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._lang = lang

    @property
    def device_type(self):
        """Gets the device_type of this PaymentSessionDetails.  # noqa: E501

        Device type, could be `desktop`, `mobile`, `smartTV`, `tablet`.  # noqa: E501

        :return: The device_type of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._device_type

    @device_type.setter
    def device_type(self, device_type):
        """Sets the device_type of this PaymentSessionDetails.

        Device type, could be `desktop`, `mobile`, `smartTV`, `tablet`.  # noqa: E501

        :param device_type: The device_type of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._device_type = device_type

    @property
    def device_model(self):
        """Gets the device_model of this PaymentSessionDetails.  # noqa: E501

        Information about the device used for the browser session (e.g., `iPhone`).  # noqa: E501

        :return: The device_model of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._device_model

    @device_model.setter
    def device_model(self, device_model):
        """Sets the device_model of this PaymentSessionDetails.

        Information about the device used for the browser session (e.g., `iPhone`).  # noqa: E501

        :param device_model: The device_model of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._device_model = device_model

    @property
    def browser(self):
        """Gets the browser of this PaymentSessionDetails.  # noqa: E501

        The browser used in this browser session (e.g., `Mobile Safari`).  # noqa: E501

        :return: The browser of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._browser

    @browser.setter
    def browser(self, browser):
        """Sets the browser of this PaymentSessionDetails.

        The browser used in this browser session (e.g., `Mobile Safari`).  # noqa: E501

        :param browser: The browser of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._browser = browser

    @property
    def browser_version(self):
        """Gets the browser_version of this PaymentSessionDetails.  # noqa: E501

        The version for the browser session (e.g., `13.1.1`).  # noqa: E501

        :return: The browser_version of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._browser_version

    @browser_version.setter
    def browser_version(self, browser_version):
        """Sets the browser_version of this PaymentSessionDetails.

        The version for the browser session (e.g., `13.1.1`).  # noqa: E501

        :param browser_version: The browser_version of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._browser_version = browser_version

    @property
    def os(self):
        """Gets the os of this PaymentSessionDetails.  # noqa: E501

        Operation system (e.g., `iOS`).  # noqa: E501

        :return: The os of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._os

    @os.setter
    def os(self, os):
        """Sets the os of this PaymentSessionDetails.

        Operation system (e.g., `iOS`).  # noqa: E501

        :param os: The os of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._os = os

    @property
    def os_version(self):
        """Gets the os_version of this PaymentSessionDetails.  # noqa: E501

        Operation system version (e.g., `13.5.1`).  # noqa: E501

        :return: The os_version of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._os_version

    @os_version.setter
    def os_version(self, os_version):
        """Sets the os_version of this PaymentSessionDetails.

        Operation system version (e.g., `13.5.1`).  # noqa: E501

        :param os_version: The os_version of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._os_version = os_version

    @property
    def source(self):
        """Gets the source of this PaymentSessionDetails.  # noqa: E501

        The source component from where the operation was generated (mostly for our SDK's).  # noqa: E501

        :return: The source of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this PaymentSessionDetails.

        The source component from where the operation was generated (mostly for our SDK's).  # noqa: E501

        :param source: The source of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._source = source

    @property
    def source_version(self):
        """Gets the source_version of this PaymentSessionDetails.  # noqa: E501

        The source component version from where the operation was generated (mostly for our SDK's).  # noqa: E501

        :return: The source_version of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._source_version

    @source_version.setter
    def source_version(self, source_version):
        """Sets the source_version of this PaymentSessionDetails.

        The source component version from where the operation was generated (mostly for our SDK's).  # noqa: E501

        :param source_version: The source_version of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._source_version = source_version

    @property
    def user_agent(self):
        """Gets the user_agent of this PaymentSessionDetails.  # noqa: E501

        Full user agent string of the browser session.  # noqa: E501

        :return: The user_agent of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._user_agent

    @user_agent.setter
    def user_agent(self, user_agent):
        """Sets the user_agent of this PaymentSessionDetails.

        Full user agent string of the browser session.  # noqa: E501

        :param user_agent: The user_agent of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._user_agent = user_agent

    @property
    def browser_accept(self):
        """Gets the browser_accept of this PaymentSessionDetails.  # noqa: E501

        Browser accept header.  # noqa: E501

        :return: The browser_accept of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._browser_accept

    @browser_accept.setter
    def browser_accept(self, browser_accept):
        """Sets the browser_accept of this PaymentSessionDetails.

        Browser accept header.  # noqa: E501

        :param browser_accept: The browser_accept of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._browser_accept = browser_accept

    @property
    def browser_color_depth(self):
        """Gets the browser_color_depth of this PaymentSessionDetails.  # noqa: E501

        The color depth of the browser session (e.g., `24`).  # noqa: E501

        :return: The browser_color_depth of this PaymentSessionDetails.  # noqa: E501
        :rtype: int
        """
        return self._browser_color_depth

    @browser_color_depth.setter
    def browser_color_depth(self, browser_color_depth):
        """Sets the browser_color_depth of this PaymentSessionDetails.

        The color depth of the browser session (e.g., `24`).  # noqa: E501

        :param browser_color_depth: The browser_color_depth of this PaymentSessionDetails.  # noqa: E501
        :type: int
        """

        self._browser_color_depth = browser_color_depth

    @property
    def browser_screen_height(self):
        """Gets the browser_screen_height of this PaymentSessionDetails.  # noqa: E501

        The screen height of the browser session (e.g., `1152`).  # noqa: E501

        :return: The browser_screen_height of this PaymentSessionDetails.  # noqa: E501
        :rtype: int
        """
        return self._browser_screen_height

    @browser_screen_height.setter
    def browser_screen_height(self, browser_screen_height):
        """Sets the browser_screen_height of this PaymentSessionDetails.

        The screen height of the browser session (e.g., `1152`).  # noqa: E501

        :param browser_screen_height: The browser_screen_height of this PaymentSessionDetails.  # noqa: E501
        :type: int
        """

        self._browser_screen_height = browser_screen_height

    @property
    def browser_screen_width(self):
        """Gets the browser_screen_width of this PaymentSessionDetails.  # noqa: E501

        The screen width of the browser session (e.g., `2048`).  # noqa: E501

        :return: The browser_screen_width of this PaymentSessionDetails.  # noqa: E501
        :rtype: int
        """
        return self._browser_screen_width

    @browser_screen_width.setter
    def browser_screen_width(self, browser_screen_width):
        """Sets the browser_screen_width of this PaymentSessionDetails.

        The screen width of the browser session (e.g., `2048`).  # noqa: E501

        :param browser_screen_width: The browser_screen_width of this PaymentSessionDetails.  # noqa: E501
        :type: int
        """

        self._browser_screen_width = browser_screen_width

    @property
    def browser_timezone_offset(self):
        """Gets the browser_timezone_offset of this PaymentSessionDetails.  # noqa: E501

        The timezone offset of the browser session (e.g., `-120`).  # noqa: E501

        :return: The browser_timezone_offset of this PaymentSessionDetails.  # noqa: E501
        :rtype: str
        """
        return self._browser_timezone_offset

    @browser_timezone_offset.setter
    def browser_timezone_offset(self, browser_timezone_offset):
        """Sets the browser_timezone_offset of this PaymentSessionDetails.

        The timezone offset of the browser session (e.g., `-120`).  # noqa: E501

        :param browser_timezone_offset: The browser_timezone_offset of this PaymentSessionDetails.  # noqa: E501
        :type: str
        """

        self._browser_timezone_offset = browser_timezone_offset

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentSessionDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PaymentSessionDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from Monei.api_client import ApiClient
from Monei.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class PaymentsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def cancel(self, id, **kwargs):  # noqa: E501
        """Cancel Payment  # noqa: E501

        Release customer's funds that were reserved earlier. You can only cancel a payment with the `AUTHORIZED` status.  This is the second half of the two-step payment flow, where first you created a payment with the `transactionType` set to `AUTH`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param CancelPaymentRequest cancel_payment_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.cancel_with_http_info(id, **kwargs)  # noqa: E501

    def cancel_with_http_info(self, id, **kwargs):  # noqa: E501
        """Cancel Payment  # noqa: E501

        Release customer's funds that were reserved earlier. You can only cancel a payment with the `AUTHORIZED` status.  This is the second half of the two-step payment flow, where first you created a payment with the `transactionType` set to `AUTH`.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param CancelPaymentRequest cancel_payment_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'cancel_payment_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `cancel`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'cancel_payment_request' in local_var_params:
            body_params = local_var_params['cancel_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}/cancel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def capture(self, id, **kwargs):  # noqa: E501
        """Capture Payment  # noqa: E501

        Capture the payment of an existing, uncaptured, payment. This is the second half of the two-step payment flow, where first you created a payment with the `transactionType` set to `AUTH`.  Uncaptured payments expire exactly seven days after they are created. If they are not captured by that point in time, they will be marked as expired and will no longer be capturable.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.capture(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param CapturePaymentRequest capture_payment_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.capture_with_http_info(id, **kwargs)  # noqa: E501

    def capture_with_http_info(self, id, **kwargs):  # noqa: E501
        """Capture Payment  # noqa: E501

        Capture the payment of an existing, uncaptured, payment. This is the second half of the two-step payment flow, where first you created a payment with the `transactionType` set to `AUTH`.  Uncaptured payments expire exactly seven days after they are created. If they are not captured by that point in time, they will be marked as expired and will no longer be capturable.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.capture_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param CapturePaymentRequest capture_payment_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'capture_payment_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method capture" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `capture`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'capture_payment_request' in local_var_params:
            body_params = local_var_params['capture_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}/capture', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def confirm(self, id, **kwargs):  # noqa: E501
        """Confirm Payment  # noqa: E501

        Confirm a payment that was created without a `paymentToken` or `paymentMethod`. You can only confirm a payment with the `PENDING` status.  You can charge a customer in two steps. First create a payment without payment details and then confirm it after you generate a `paymentToken` on the front-end with monei.js [Components](https://docs.monei.com/docs/monei-js-overview).  You can provide additional customer information, it will override the information passed in **create payment** request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param ConfirmPaymentRequest confirm_payment_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.confirm_with_http_info(id, **kwargs)  # noqa: E501

    def confirm_with_http_info(self, id, **kwargs):  # noqa: E501
        """Confirm Payment  # noqa: E501

        Confirm a payment that was created without a `paymentToken` or `paymentMethod`. You can only confirm a payment with the `PENDING` status.  You can charge a customer in two steps. First create a payment without payment details and then confirm it after you generate a `paymentToken` on the front-end with monei.js [Components](https://docs.monei.com/docs/monei-js-overview).  You can provide additional customer information, it will override the information passed in **create payment** request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.confirm_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param ConfirmPaymentRequest confirm_payment_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'confirm_payment_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method confirm" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `confirm`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'confirm_payment_request' in local_var_params:
            body_params = local_var_params['confirm_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}/confirm', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create(self, create_payment_request, **kwargs):  # noqa: E501
        """Create Payment  # noqa: E501

        To charge a credit card or other payment method, you create a Payment.  Payment can also be created without a payment method to initiate a payment process and redirect a customer to the hosted payment page.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create(create_payment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePaymentRequest create_payment_request: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_with_http_info(create_payment_request, **kwargs)  # noqa: E501

    def create_with_http_info(self, create_payment_request, **kwargs):  # noqa: E501
        """Create Payment  # noqa: E501

        To charge a credit card or other payment method, you create a Payment.  Payment can also be created without a payment method to initiate a payment process and redirect a customer to the hosted payment page.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_with_http_info(create_payment_request, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreatePaymentRequest create_payment_request: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_payment_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_payment_request' is set
        if self.api_client.client_side_validation and ('create_payment_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_payment_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_payment_request` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_payment_request' in local_var_params:
            body_params = local_var_params['create_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get(self, id, **kwargs):  # noqa: E501
        """Get Payment  # noqa: E501

        Get the details of a payment that has previously been created. Supply the unique payment ID that was returned from your previous request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_with_http_info(id, **kwargs)  # noqa: E501

    def get_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get Payment  # noqa: E501

        Get the details of a payment that has previously been created. Supply the unique payment ID that was returned from your previous request.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def recurring(self, sequence_id, **kwargs):  # noqa: E501
        """Recurring Payment  # noqa: E501

        Creates a subsequent operation for a recurring payment, previously created. The specified amount will be charged to the same credit or debit card of the originally payment.  If amount is not specified, it will default to the same amount from the original payment.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.recurring(sequence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sequence_id: The sequence ID (required)
        :param RecurringPaymentRequest recurring_payment_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.recurring_with_http_info(sequence_id, **kwargs)  # noqa: E501

    def recurring_with_http_info(self, sequence_id, **kwargs):  # noqa: E501
        """Recurring Payment  # noqa: E501

        Creates a subsequent operation for a recurring payment, previously created. The specified amount will be charged to the same credit or debit card of the originally payment.  If amount is not specified, it will default to the same amount from the original payment.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.recurring_with_http_info(sequence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str sequence_id: The sequence ID (required)
        :param RecurringPaymentRequest recurring_payment_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'sequence_id',
            'recurring_payment_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recurring" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'sequence_id' is set
        if self.api_client.client_side_validation and ('sequence_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['sequence_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `sequence_id` when calling `recurring`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'sequence_id' in local_var_params:
            path_params['sequenceId'] = local_var_params['sequence_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'recurring_payment_request' in local_var_params:
            body_params = local_var_params['recurring_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{sequenceId}/recurring', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def refund(self, id, **kwargs):  # noqa: E501
        """Refund Payment  # noqa: E501

        Refund a payment that has previously been created but not yet refunded. Funds will be refunded to the credit or debit card that was originally charged.  You can optionally refund only part of a payment. You can do so multiple times, until the entire payment has been refunded.  Once entirely refunded, a payment can’t be refunded again. This method will throw an error when called on an already-refunded payment, or when trying to refund more money than is left on a payment.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refund(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param RefundPaymentRequest refund_payment_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.refund_with_http_info(id, **kwargs)  # noqa: E501

    def refund_with_http_info(self, id, **kwargs):  # noqa: E501
        """Refund Payment  # noqa: E501

        Refund a payment that has previously been created but not yet refunded. Funds will be refunded to the credit or debit card that was originally charged.  You can optionally refund only part of a payment. You can do so multiple times, until the entire payment has been refunded.  Once entirely refunded, a payment can’t be refunded again. This method will throw an error when called on an already-refunded payment, or when trying to refund more money than is left on a payment.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.refund_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param RefundPaymentRequest refund_payment_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'refund_payment_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method refund" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `refund`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'refund_payment_request' in local_var_params:
            body_params = local_var_params['refund_payment_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}/refund', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_link(self, id, **kwargs):  # noqa: E501
        """Send Payment Link  # noqa: E501

        Sends a payment link to the customer via email.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_link(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param SendPaymentLinkRequest send_payment_link_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.send_link_with_http_info(id, **kwargs)  # noqa: E501

    def send_link_with_http_info(self, id, **kwargs):  # noqa: E501
        """Send Payment Link  # noqa: E501

        Sends a payment link to the customer via email.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_link_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param SendPaymentLinkRequest send_payment_link_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'send_payment_link_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_link" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `send_link`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_payment_link_request' in local_var_params:
            body_params = local_var_params['send_payment_link_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}/link', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def send_receipt(self, id, **kwargs):  # noqa: E501
        """Send Payment Receipt  # noqa: E501

        Sends a payment receipt to the customer via email.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_receipt(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param SendPaymentReceiptRequest send_payment_receipt_request:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Payment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.send_receipt_with_http_info(id, **kwargs)  # noqa: E501

    def send_receipt_with_http_info(self, id, **kwargs):  # noqa: E501
        """Send Payment Receipt  # noqa: E501

        Sends a payment receipt to the customer via email.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.send_receipt_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str id: The payment ID (required)
        :param SendPaymentReceiptRequest send_payment_receipt_request:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Payment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'id',
            'send_payment_receipt_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method send_receipt" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `send_receipt`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'send_payment_receipt_request' in local_var_params:
            body_params = local_var_params['send_payment_receipt_request']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['APIKey']  # noqa: E501

        return self.api_client.call_api(
            '/payments/{id}/receipt', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Payment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from Monei.configuration import Configuration


class CreatePaymentRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'amount': 'int',
        'currency': 'str',
        'order_id': 'str',
        'callback_url': 'str',
        'complete_url': 'str',
        'fail_url': 'str',
        'cancel_url': 'str',
        'payment_token': 'str',
        'session_id': 'str',
        'generate_payment_token': 'bool',
        'payment_method': 'PaymentPaymentMethodInput',
        'allowed_payment_methods': 'PaymentPaymentMethods',
        'transaction_type': 'PaymentTransactionType',
        'sequence': 'PaymentSequence',
        'point_of_sale_id': 'str',
        'subscription_id': 'str',
        'auto_recover': 'bool',
        'description': 'str',
        'customer': 'PaymentCustomer',
        'billing_details': 'PaymentBillingDetails',
        'shipping_details': 'PaymentShippingDetails',
        'session_details': 'PaymentSessionDetails'
    }

    attribute_map = {
        'amount': 'amount',
        'currency': 'currency',
        'order_id': 'orderId',
        'callback_url': 'callbackUrl',
        'complete_url': 'completeUrl',
        'fail_url': 'failUrl',
        'cancel_url': 'cancelUrl',
        'payment_token': 'paymentToken',
        'session_id': 'sessionId',
        'generate_payment_token': 'generatePaymentToken',
        'payment_method': 'paymentMethod',
        'allowed_payment_methods': 'allowedPaymentMethods',
        'transaction_type': 'transactionType',
        'sequence': 'sequence',
        'point_of_sale_id': 'pointOfSaleId',
        'subscription_id': 'subscriptionId',
        'auto_recover': 'autoRecover',
        'description': 'description',
        'customer': 'customer',
        'billing_details': 'billingDetails',
        'shipping_details': 'shippingDetails',
        'session_details': 'sessionDetails'
    }

    def __init__(self, amount=None, currency=None, order_id=None, callback_url=None, complete_url=None, fail_url=None, cancel_url=None, payment_token=None, session_id=None, generate_payment_token=False, payment_method=None, allowed_payment_methods=None, transaction_type=None, sequence=None, point_of_sale_id=None, subscription_id=None, auto_recover=None, description=None, customer=None, billing_details=None, shipping_details=None, session_details=None, local_vars_configuration=None):  # noqa: E501
        """CreatePaymentRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._amount = None
        self._currency = None
        self._order_id = None
        self._callback_url = None
        self._complete_url = None
        self._fail_url = None
        self._cancel_url = None
        self._payment_token = None
        self._session_id = None
        self._generate_payment_token = None
        self._payment_method = None
        self._allowed_payment_methods = None
        self._transaction_type = None
        self._sequence = None
        self._point_of_sale_id = None
        self._subscription_id = None
        self._auto_recover = None
        self._description = None
        self._customer = None
        self._billing_details = None
        self._shipping_details = None
        self._session_details = None
        self.discriminator = None

        self.amount = amount
        self.currency = currency
        self.order_id = order_id
        if callback_url is not None:
            self.callback_url = callback_url
        if complete_url is not None:
            self.complete_url = complete_url
        if fail_url is not None:
            self.fail_url = fail_url
        if cancel_url is not None:
            self.cancel_url = cancel_url
        if payment_token is not None:
            self.payment_token = payment_token
        if session_id is not None:
            self.session_id = session_id
        if generate_payment_token is not None:
            self.generate_payment_token = generate_payment_token
        if payment_method is not None:
            self.payment_method = payment_method
        if allowed_payment_methods is not None:
            self.allowed_payment_methods = allowed_payment_methods
        if transaction_type is not None:
            self.transaction_type = transaction_type
        if sequence is not None:
            self.sequence = sequence
        if point_of_sale_id is not None:
            self.point_of_sale_id = point_of_sale_id
        if subscription_id is not None:
            self.subscription_id = subscription_id
        if auto_recover is not None:
            self.auto_recover = auto_recover
        if description is not None:
            self.description = description
        if customer is not None:
            self.customer = customer
        if billing_details is not None:
            self.billing_details = billing_details
        if shipping_details is not None:
            self.shipping_details = shipping_details
        if session_details is not None:
            self.session_details = session_details

    @property
    def amount(self):
        """Gets the amount of this CreatePaymentRequest.  # noqa: E501

        Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge 1.00 USD).   # noqa: E501

        :return: The amount of this CreatePaymentRequest.  # noqa: E501
        :rtype: int
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this CreatePaymentRequest.

        Amount intended to be collected by this payment. A positive integer representing how much to charge in the smallest currency unit (e.g., 100 cents to charge 1.00 USD).   # noqa: E501

        :param amount: The amount of this CreatePaymentRequest.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    @property
    def currency(self):
        """Gets the currency of this CreatePaymentRequest.  # noqa: E501

        Three-letter [ISO currency code](https://en.wikipedia.org/wiki/ISO_4217), in uppercase. Must be a supported currency.   # noqa: E501

        :return: The currency of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this CreatePaymentRequest.

        Three-letter [ISO currency code](https://en.wikipedia.org/wiki/ISO_4217), in uppercase. Must be a supported currency.   # noqa: E501

        :param currency: The currency of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and currency is None:  # noqa: E501
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def order_id(self):
        """Gets the order_id of this CreatePaymentRequest.  # noqa: E501

        An order ID from your system. A unique identifier that can be used to reconcile the payment with your internal system.   # noqa: E501

        :return: The order_id of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """Sets the order_id of this CreatePaymentRequest.

        An order ID from your system. A unique identifier that can be used to reconcile the payment with your internal system.   # noqa: E501

        :param order_id: The order_id of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and order_id is None:  # noqa: E501
            raise ValueError("Invalid value for `order_id`, must not be `None`")  # noqa: E501

        self._order_id = order_id

    @property
    def callback_url(self):
        """Gets the callback_url of this CreatePaymentRequest.  # noqa: E501

        The URL to which a payment result should be sent asynchronously.   # noqa: E501

        :return: The callback_url of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._callback_url

    @callback_url.setter
    def callback_url(self, callback_url):
        """Sets the callback_url of this CreatePaymentRequest.

        The URL to which a payment result should be sent asynchronously.   # noqa: E501

        :param callback_url: The callback_url of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._callback_url = callback_url

    @property
    def complete_url(self):
        """Gets the complete_url of this CreatePaymentRequest.  # noqa: E501

        The URL the customer will be directed to after transaction completed (successful or failed - except if `failUrl` is provided).   # noqa: E501

        :return: The complete_url of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._complete_url

    @complete_url.setter
    def complete_url(self, complete_url):
        """Sets the complete_url of this CreatePaymentRequest.

        The URL the customer will be directed to after transaction completed (successful or failed - except if `failUrl` is provided).   # noqa: E501

        :param complete_url: The complete_url of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._complete_url = complete_url

    @property
    def fail_url(self):
        """Gets the fail_url of this CreatePaymentRequest.  # noqa: E501

        The URL the customer will be directed to after transaction has failed, instead of `completeUrl` (used in hosted payment page). This allows to provide two different URLs for successful and failed payments.   # noqa: E501

        :return: The fail_url of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._fail_url

    @fail_url.setter
    def fail_url(self, fail_url):
        """Sets the fail_url of this CreatePaymentRequest.

        The URL the customer will be directed to after transaction has failed, instead of `completeUrl` (used in hosted payment page). This allows to provide two different URLs for successful and failed payments.   # noqa: E501

        :param fail_url: The fail_url of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._fail_url = fail_url

    @property
    def cancel_url(self):
        """Gets the cancel_url of this CreatePaymentRequest.  # noqa: E501

        The URL the customer will be directed to if they decide to cancel payment and return to your website (used in hosted payment page).   # noqa: E501

        :return: The cancel_url of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._cancel_url

    @cancel_url.setter
    def cancel_url(self, cancel_url):
        """Sets the cancel_url of this CreatePaymentRequest.

        The URL the customer will be directed to if they decide to cancel payment and return to your website (used in hosted payment page).   # noqa: E501

        :param cancel_url: The cancel_url of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._cancel_url = cancel_url

    @property
    def payment_token(self):
        """Gets the payment_token of this CreatePaymentRequest.  # noqa: E501

        A payment token generated by monei.js [Components](https://docs.monei.com/docs/monei-js-overview) or a paymentToken [saved after a previous successful payment](https://docs.monei.com/docs/save-payment-method). In case of the first one, you will also need to send the `sessionId` used to generate the token in the first place.   # noqa: E501

        :return: The payment_token of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._payment_token

    @payment_token.setter
    def payment_token(self, payment_token):
        """Sets the payment_token of this CreatePaymentRequest.

        A payment token generated by monei.js [Components](https://docs.monei.com/docs/monei-js-overview) or a paymentToken [saved after a previous successful payment](https://docs.monei.com/docs/save-payment-method). In case of the first one, you will also need to send the `sessionId` used to generate the token in the first place.   # noqa: E501

        :param payment_token: The payment_token of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._payment_token = payment_token

    @property
    def session_id(self):
        """Gets the session_id of this CreatePaymentRequest.  # noqa: E501

        A unique identifier within your system that adds security to the payment process. You need to pass the same session ID as the one used on the frontend to initialize MONEI Component (if you needed to). This is required if a payment token (not permanent) was already generated in the frontend.   # noqa: E501

        :return: The session_id of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._session_id

    @session_id.setter
    def session_id(self, session_id):
        """Sets the session_id of this CreatePaymentRequest.

        A unique identifier within your system that adds security to the payment process. You need to pass the same session ID as the one used on the frontend to initialize MONEI Component (if you needed to). This is required if a payment token (not permanent) was already generated in the frontend.   # noqa: E501

        :param session_id: The session_id of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._session_id = session_id

    @property
    def generate_payment_token(self):
        """Gets the generate_payment_token of this CreatePaymentRequest.  # noqa: E501

        If set to true a permanent token that represents a payment method used in the payment will be generated.   # noqa: E501

        :return: The generate_payment_token of this CreatePaymentRequest.  # noqa: E501
        :rtype: bool
        """
        return self._generate_payment_token

    @generate_payment_token.setter
    def generate_payment_token(self, generate_payment_token):
        """Sets the generate_payment_token of this CreatePaymentRequest.

        If set to true a permanent token that represents a payment method used in the payment will be generated.   # noqa: E501

        :param generate_payment_token: The generate_payment_token of this CreatePaymentRequest.  # noqa: E501
        :type: bool
        """

        self._generate_payment_token = generate_payment_token

    @property
    def payment_method(self):
        """Gets the payment_method of this CreatePaymentRequest.  # noqa: E501


        :return: The payment_method of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentPaymentMethodInput
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this CreatePaymentRequest.


        :param payment_method: The payment_method of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentPaymentMethodInput
        """

        self._payment_method = payment_method

    @property
    def allowed_payment_methods(self):
        """Gets the allowed_payment_methods of this CreatePaymentRequest.  # noqa: E501


        :return: The allowed_payment_methods of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentPaymentMethods
        """
        return self._allowed_payment_methods

    @allowed_payment_methods.setter
    def allowed_payment_methods(self, allowed_payment_methods):
        """Sets the allowed_payment_methods of this CreatePaymentRequest.


        :param allowed_payment_methods: The allowed_payment_methods of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentPaymentMethods
        """

        self._allowed_payment_methods = allowed_payment_methods

    @property
    def transaction_type(self):
        """Gets the transaction_type of this CreatePaymentRequest.  # noqa: E501


        :return: The transaction_type of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentTransactionType
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this CreatePaymentRequest.


        :param transaction_type: The transaction_type of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentTransactionType
        """

        self._transaction_type = transaction_type

    @property
    def sequence(self):
        """Gets the sequence of this CreatePaymentRequest.  # noqa: E501


        :return: The sequence of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentSequence
        """
        return self._sequence

    @sequence.setter
    def sequence(self, sequence):
        """Sets the sequence of this CreatePaymentRequest.


        :param sequence: The sequence of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentSequence
        """

        self._sequence = sequence

    @property
    def point_of_sale_id(self):
        """Gets the point_of_sale_id of this CreatePaymentRequest.  # noqa: E501

        A unique identifier of the Point of Sale. If specified the payment is attached to this Point of Sale. If there is a QR code attached to the same Point of Sale, this payment will be available by scanning the QR code.   # noqa: E501

        :return: The point_of_sale_id of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._point_of_sale_id

    @point_of_sale_id.setter
    def point_of_sale_id(self, point_of_sale_id):
        """Sets the point_of_sale_id of this CreatePaymentRequest.

        A unique identifier of the Point of Sale. If specified the payment is attached to this Point of Sale. If there is a QR code attached to the same Point of Sale, this payment will be available by scanning the QR code.   # noqa: E501

        :param point_of_sale_id: The point_of_sale_id of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._point_of_sale_id = point_of_sale_id

    @property
    def subscription_id(self):
        """Gets the subscription_id of this CreatePaymentRequest.  # noqa: E501

        A unique identifier of the Subscription. If specified the payment is attached to this Subscription.   # noqa: E501

        :return: The subscription_id of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """Sets the subscription_id of this CreatePaymentRequest.

        A unique identifier of the Subscription. If specified the payment is attached to this Subscription.   # noqa: E501

        :param subscription_id: The subscription_id of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._subscription_id = subscription_id

    @property
    def auto_recover(self):
        """Gets the auto_recover of this CreatePaymentRequest.  # noqa: E501

        If set to `true`, the new payment will be automatically created when customer visits the payment link of the previously failed payment. Is automatically set to `true` if `completeUrl` is not provided.(set this value to `true` to create \"Pay By Link\" payments).  # noqa: E501

        :return: The auto_recover of this CreatePaymentRequest.  # noqa: E501
        :rtype: bool
        """
        return self._auto_recover

    @auto_recover.setter
    def auto_recover(self, auto_recover):
        """Sets the auto_recover of this CreatePaymentRequest.

        If set to `true`, the new payment will be automatically created when customer visits the payment link of the previously failed payment. Is automatically set to `true` if `completeUrl` is not provided.(set this value to `true` to create \"Pay By Link\" payments).  # noqa: E501

        :param auto_recover: The auto_recover of this CreatePaymentRequest.  # noqa: E501
        :type: bool
        """

        self._auto_recover = auto_recover

    @property
    def description(self):
        """Gets the description of this CreatePaymentRequest.  # noqa: E501

        An arbitrary string attached to the payment. Often useful for displaying to users.   # noqa: E501

        :return: The description of this CreatePaymentRequest.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreatePaymentRequest.

        An arbitrary string attached to the payment. Often useful for displaying to users.   # noqa: E501

        :param description: The description of this CreatePaymentRequest.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def customer(self):
        """Gets the customer of this CreatePaymentRequest.  # noqa: E501


        :return: The customer of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentCustomer
        """
        return self._customer

    @customer.setter
    def customer(self, customer):
        """Sets the customer of this CreatePaymentRequest.


        :param customer: The customer of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentCustomer
        """

        self._customer = customer

    @property
    def billing_details(self):
        """Gets the billing_details of this CreatePaymentRequest.  # noqa: E501


        :return: The billing_details of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentBillingDetails
        """
        return self._billing_details

    @billing_details.setter
    def billing_details(self, billing_details):
        """Sets the billing_details of this CreatePaymentRequest.


        :param billing_details: The billing_details of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentBillingDetails
        """

        self._billing_details = billing_details

    @property
    def shipping_details(self):
        """Gets the shipping_details of this CreatePaymentRequest.  # noqa: E501


        :return: The shipping_details of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentShippingDetails
        """
        return self._shipping_details

    @shipping_details.setter
    def shipping_details(self, shipping_details):
        """Sets the shipping_details of this CreatePaymentRequest.


        :param shipping_details: The shipping_details of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentShippingDetails
        """

        self._shipping_details = shipping_details

    @property
    def session_details(self):
        """Gets the session_details of this CreatePaymentRequest.  # noqa: E501


        :return: The session_details of this CreatePaymentRequest.  # noqa: E501
        :rtype: PaymentSessionDetails
        """
        return self._session_details

    @session_details.setter
    def session_details(self, session_details):
        """Sets the session_details of this CreatePaymentRequest.


        :param session_details: The session_details of this CreatePaymentRequest.  # noqa: E501
        :type: PaymentSessionDetails
        """

        self._session_details = session_details

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreatePaymentRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreatePaymentRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. <br/><br/> **Base URL:** https://api.monei.com/v1 <br/><br/> **Client libraries:** <ul>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li>   <li><a target=\"_blank\" href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>  # noqa: E501

    The version of the OpenAPI document: 1.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import Monei
from Monei.models.create_subscription_request import CreateSubscriptionRequest  # noqa: E501
from Monei.rest import ApiException

class TestCreateSubscriptionRequest(unittest.TestCase):
    """CreateSubscriptionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateSubscriptionRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = Monei.models.create_subscription_request.CreateSubscriptionRequest()  # noqa: E501
        if include_optional :
            return CreateSubscriptionRequest(
                amount = 110, 
                currency = 'EUR', 
                interval = 'month', 
                interval_count = 1, 
                description = 'MoonMail Monthly Lite', 
                customer = Monei.models.payment_customer.Payment-Customer(
                    email = 'john.doe@example.com', 
                    name = 'John Doe', 
                    phone = '0', ), 
                billing_details = Monei.models.payment_billing_details.Payment-BillingDetails(
                    name = 'John Doe', 
                    email = 'john.doe@example.com', 
                    phone = '0', 
                    company = '0', 
                    address = Monei.models.address.Address(
                        country = 'ES', 
                        city = 'Málaga', 
                        line1 = 'Fake Street 123', 
                        line2 = '0', 
                        zip = '1234', 
                        state = 'Málaga', ), ), 
                shipping_details = Monei.models.payment_shipping_details.Payment-ShippingDetails(
                    name = 'John Doe', 
                    email = 'john.doe@example.com', 
                    phone = '0', 
                    company = '0', 
                    address = Monei.models.address.Address(
                        country = 'ES', 
                        city = 'Málaga', 
                        line1 = 'Fake Street 123', 
                        line2 = '0', 
                        zip = '1234', 
                        state = 'Málaga', ), ), 
                trial_period_end = 1636366897, 
                trial_period_days = 7, 
                callback_url = 'https://example.com/subscriptions/callback', 
                payment_callback_url = 'https://example.com/payments/callback'
            )
        else :
            return CreateSubscriptionRequest(
                amount = 110,
                currency = 'EUR',
                interval = 'month',
                interval_count = 1,
                callback_url = 'https://example.com/subscriptions/callback',
                payment_callback_url = 'https://example.com/payments/callback',
        )

    def testCreateSubscriptionRequest(self):
        """Test CreateSubscriptionRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import MONEI PYTHON SDK
from MONEI PYTHON SDK.models.payment import Payment  # noqa: E501
from MONEI PYTHON SDK.rest import ApiException

class TestPayment(unittest.TestCase):
    """Payment unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Payment
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = MONEI PYTHON SDK.models.payment.Payment()  # noqa: E501
        if include_optional :
            return Payment(
                id = 'af6029f80f5fc73a8ad2753eea0b1be0',
                amount = 110,
                currency = 'EUR',
                order_id = '14379133960355',
                description = 'Test Shop - #84370745531439',
                account_id = 'aa9333ba-82de-400c-9ae7-087b9f8d2242',
                authorization_code = '475816',
                livemode = False,
                status = 'PENDING',
                status_code = '0',
                status_message = '0',
                customer = MONEI PYTHON SDK.models.payment_customer.Payment-Customer(
                    email = 'john.doe@microapps.com',
                    name = 'John Doe',
                    phone = '0', ),
                payment_token = '7cc38b08ff471ccd313ad62b23b9f362b107560b',
                payment_method = MONEI PYTHON SDK.models.payment_payment_method.Payment-PaymentMethod(
                    method = 'card',
                    card = MONEI PYTHON SDK.models.payment_payment_method_card.Payment-PaymentMethodCard(
                        country = 'ES',
                        brand = 'visa',
                        type = 'credit',
                        three_d_secure = False,
                        three_d_secure_version = '2.1.0',
                        last4 = '0004', ),
                    bizum = MONEI PYTHON SDK.models.payment_payment_method_bizum.Payment-PaymentMethodBizum(
                        phone_number = '0', ),
                    paypal = MONEI PYTHON SDK.models.payment_payment_method_paypal.Payment-PaymentMethodPaypal(
                        order_id = '0', ), ),
                shop = MONEI PYTHON SDK.models.payment_shop.Payment-Shop(
                    name = 'Test Shop',
                    country = 'ES', ),
                billing_details = MONEI PYTHON SDK.models.payment_billing_details.Payment-BillingDetails(
                    name = 'John Doe',
                    email = 'john.doe@microapps.com',
                    phone = '0',
                    company = '0',
                    address = MONEI PYTHON SDK.models.address.Address(
                        country = 'ES',
                        city = 'Málaga',
                        line1 = 'Fake Street 123',
                        line2 = '0',
                        zip = '1234',
                        state = 'Málaga', ), ),
                shipping_details = MONEI PYTHON SDK.models.payment_shipping_details.Payment-ShippingDetails(
                    name = 'John Doe',
                    email = 'john.doe@microapps.com',
                    phone = '0',
                    company = '0',
                    address = MONEI PYTHON SDK.models.address.Address(
                        country = 'ES',
                        city = 'Málaga',
                        line1 = 'Fake Street 123',
                        line2 = '0',
                        zip = '1234',
                        state = 'Málaga', ), ),
                refunded_amount = 56,
                last_refund_amount = 56,
                last_refund_reason = 'duplicated',
                cancellation_reason = 'duplicated',
                session_details = MONEI PYTHON SDK.models.payment_session_details.Payment-SessionDetails(
                    ip = '100.100.200.100',
                    country_code = 'ES',
                    lang = 'es',
                    device_type = 'desktop',
                    device_model = '0',
                    browser = 'Chrome',
                    browser_version = '83.0.4103.116',
                    os = 'Mac OS',
                    os_version = '10.15.4',
                    source = 'MONEI/PHP',
                    source_version = '0.1.2',
                    user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) ...', ),
                trace_details = MONEI PYTHON SDK.models.payment_trace_details.Payment-TraceDetails(
                    ip = '100.100.200.100',
                    country_code = 'ES',
                    lang = 'es',
                    device_type = 'desktop',
                    device_model = '0',
                    browser = 'Chrome',
                    browser_version = '83.0.4103.116',
                    os = 'Mac OS',
                    os_version = '10.15.4',
                    source = 'MONEI/PHP',
                    source_version = '0.1.2',
                    user_agent = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) ...',
                    user_id = '0',
                    user_email = 'user@example.com', ),
                next_action = MONEI PYTHON SDK.models.payment_next_action.Payment-NextAction(
                    type = 'CONFIRM',
                    must_redirect = False,
                    redirect_url = 'https://secure.monei.com/payments/af6029f80f5fc73a8ad2753eea0b1be0', ),
                created_at = 56,
                updated_at = 56
            )
        else :
            return Payment(
        )

    def testPayment(self):
        """Test Payment"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. <br/><br/> **Base URL:** https://api.monei.com/v1 <br/><br/> **Client libraries:** <ul>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li>   <li><a target=\"_blank\" href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>  # noqa: E501

    The version of the OpenAPI document: 1.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import Monei
from Monei.models.pause_subscription_request import PauseSubscriptionRequest  # noqa: E501
from Monei.rest import ApiException

class TestPauseSubscriptionRequest(unittest.TestCase):
    """PauseSubscriptionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PauseSubscriptionRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = Monei.models.pause_subscription_request.PauseSubscriptionRequest()  # noqa: E501
        if include_optional :
            return PauseSubscriptionRequest(
                pause_at_period_end = False, 
                pause_interval_count = 1
            )
        else :
            return PauseSubscriptionRequest(
        )

    def testPauseSubscriptionRequest(self):
        """Test PauseSubscriptionRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import MONEI PYTHON SDK
from MONEI PYTHON SDK.models.payment_billing_details import PaymentBillingDetails  # noqa: E501
from MONEI PYTHON SDK.rest import ApiException

class TestPaymentBillingDetails(unittest.TestCase):
    """PaymentBillingDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PaymentBillingDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = MONEI PYTHON SDK.models.payment_billing_details.PaymentBillingDetails()  # noqa: E501
        if include_optional :
            return PaymentBillingDetails(
                name = 'John Doe', 
                email = 'john.doe@microapps.com', 
                phone = '0', 
                company = '0', 
                address = MONEI PYTHON SDK.models.address.Address(
                    country = 'ES', 
                    city = 'Málaga', 
                    line1 = 'Fake Street 123', 
                    line2 = '0', 
                    zip = '1234', 
                    state = 'Málaga', )
            )
        else :
            return PaymentBillingDetails(
        )

    def testPaymentBillingDetails(self):
        """Test PaymentBillingDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import MONEI PYTHON SDK
from MONEI PYTHON SDK.models.card import Card  # noqa: E501
from MONEI PYTHON SDK.rest import ApiException

class TestCard(unittest.TestCase):
    """Card unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Card
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = MONEI PYTHON SDK.models.card.Card()  # noqa: E501
        if include_optional :
            return Card(
                number = '0', 
                cvc = '0', 
                exp_month = '0', 
                exp_year = '0'
            )
        else :
            return Card(
        )

    def testCard(self):
        """Test Card"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    MONEI API v1

    <p>The MONEI API is organized around <a href=\"https://en.wikipedia.org/wiki/Representational_State_Transfer\">REST</a>. Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs.</p> <h4 id=\"base-url\">Base URL:</h4> <p><a href=\"https://api.monei.com/v1\">https://api.monei.com/v1</a></p> <h4 id=\"client-libraries\">Client libraries:</h4> <ul> <li><a href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li> <li><a href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li> <li><a href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>   # noqa: E501

    The version of the OpenAPI document: 1.2.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from Monei.models.activate_subscription_request import ActivateSubscriptionRequest
from Monei.models.address import Address
from Monei.models.cancel_payment_request import CancelPaymentRequest
from Monei.models.cancel_subscription_request import CancelSubscriptionRequest
from Monei.models.capture_payment_request import CapturePaymentRequest
from Monei.models.card import Card
from Monei.models.confirm_payment_request import ConfirmPaymentRequest
from Monei.models.confirm_payment_request_payment_method import ConfirmPaymentRequestPaymentMethod
from Monei.models.confirm_payment_request_payment_method_card import ConfirmPaymentRequestPaymentMethodCard
from Monei.models.create_payment_request import CreatePaymentRequest
from Monei.models.create_subscription_request import CreateSubscriptionRequest
from Monei.models.error import Error
from Monei.models.inline_response200 import InlineResponse200
from Monei.models.pause_subscription_request import PauseSubscriptionRequest
from Monei.models.payment import Payment
from Monei.models.payment_billing_details import PaymentBillingDetails
from Monei.models.payment_cancellation_reason import PaymentCancellationReason
from Monei.models.payment_customer import PaymentCustomer
from Monei.models.payment_last_refund_reason import PaymentLastRefundReason
from Monei.models.payment_next_action import PaymentNextAction
from Monei.models.payment_payment_method import PaymentPaymentMethod
from Monei.models.payment_payment_method_bizum import PaymentPaymentMethodBizum
from Monei.models.payment_payment_method_card import PaymentPaymentMethodCard
from Monei.models.payment_payment_method_cofidis import PaymentPaymentMethodCofidis
from Monei.models.payment_payment_method_input import PaymentPaymentMethodInput
from Monei.models.payment_payment_method_paypal import PaymentPaymentMethodPaypal
from Monei.models.payment_refund_reason import PaymentRefundReason
from Monei.models.payment_sequence import PaymentSequence
from Monei.models.payment_sequence_recurring import PaymentSequenceRecurring
from Monei.models.payment_session_details import PaymentSessionDetails
from Monei.models.payment_shipping_details import PaymentShippingDetails
from Monei.models.payment_shop import PaymentShop
from Monei.models.payment_status import PaymentStatus
from Monei.models.payment_trace_details import PaymentTraceDetails
from Monei.models.payment_transaction_type import PaymentTransactionType
from Monei.models.recurring_payment_request import RecurringPaymentRequest
from Monei.models.refund_payment_request import RefundPaymentRequest
from Monei.models.register_domain_request import RegisterDomainRequest
from Monei.models.send_payment_link_request import SendPaymentLinkRequest
from Monei.models.send_payment_receipt_request import SendPaymentReceiptRequest
from Monei.models.subscription import Subscription
from Monei.models.subscription_interval import SubscriptionInterval
from Monei.models.subscription_last_payment import SubscriptionLastPayment
from Monei.models.subscription_payment_method import SubscriptionPaymentMethod
from Monei.models.subscription_payment_method_card import SubscriptionPaymentMethodCard
from Monei.models.subscription_status import SubscriptionStatus
from Monei.models.update_subscription_request import UpdateSubscriptionRequest



# coding: utf-8

"""
    MONEI API v1

    The MONEI API is organized around [REST](https://en.wikipedia.org/wiki/Representational_State_Transfer). Our API has predictable resource-oriented URLs, accepts JSON-encoded request bodies, returns JSON-encoded responses, and uses standard HTTP response codes, authentication, and verbs. <br/><br/> **Base URL:** https://api.monei.com/v1 <br/><br/> **Client libraries:** <ul>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-php-sdk\">PHP SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-python-sdk\">Python SDK</a></li>   <li><a target=\"_blank\" href=\"https://github.com/MONEI/monei-node-sdk\">Node.js SDK</a></li>   <li><a target=\"_blank\" href=\"https://postman.monei.com/\">Postman Collection</a></li> </ul>  # noqa: E501

    The version of the OpenAPI document: 1.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import Monei
from Monei.api.subscriptions_api import SubscriptionsApi  # noqa: E501
from Monei.rest import ApiException


class TestSubscriptionsApi(unittest.TestCase):
    """SubscriptionsApi unit test stubs"""

    def setUp(self):
        self.api = Monei.api.subscriptions_api.SubscriptionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate(self):
        """Test case for activate

        Activate Subscription  # noqa: E501
        """
        pass

    def test_cancel(self):
        """Test case for cancel

        Cancel Subscription  # noqa: E501
        """
        pass

    def test_create(self):
        """Test case for create

        Create Subscription  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get Subscription  # noqa: E501
        """
        pass

    def test_pause(self):
        """Test case for pause

        Pause Subscription  # noqa: E501
        """
        pass

    def test_resume(self):
        """Test case for resume

        Resume Subscription  # noqa: E501
        """
        pass

    def test_update(self):
        """Test case for update

        Update Subscription  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
